# Western boundary current theory

## Motivation {#motivation .unnumbered}

We have seen that the Sverdrup balance ties together the surface Ekman
layer and the geostrophic interior (which actually overlaps with the
Ekman layer), yielding a prediction of the vertically-integrated
meridional velocity as a function of the curl of the wind stress. Using
conservation of mass, we can then calculate the zonal velocity component
as well, provided we can integrate from a point in the middle of the
basin all the way to the eastern boundary of the basin. This leads to
two questions: (1) why do we integrate to the eastern boundary, not the
western? (2) how do we close the mass budget, that is, ensure that
across any basin-wide zonal line the net meridional transport is zero?
The answer to both questions requires the concept of a western boundary
current, a particular type of boundary layer.

## Boundary layers {#boundary-layers .unnumbered}

The **boundary layer** concept occurs often in fluid mechanics. Recall
that to make progress in understanding any particular fluid flow, we
almost always have to simplify the situation---figure out what are the
essential elements in the dynamical balance, and ignore everything else.
The essential elements may be different in different parts of the
domain, however, and in particular there are often relatively thin
layers around the boundaries where the dominant force balance is quite
different from what it is in the interior of the domain. Typically, it
is friction that becomes important in a boundary layer, whereas the
interior can be approximated as inviscid. The Ekman layer is an example
of a frictional boundary layer. Sometimes the essential new element in
the boundary layer is not friction but nonlinearity, brought about by
strong flow and short spatial scales (such as the thickness of the
layer).

## Why is it just on the western boundary? {#why-is-it-just-on-the-western-boundary .unnumbered}

Now, the Sverdrup balance relates the vertically-integrated meridional
flow to the curl of the wind stress, which could, for example, be
independent of longitude. Then there would be a net Sverdrup transport
to the south (given negative curl in the northern hemisphere)---but in a
closed basin, this cannot be a complete steady-state solution. For a
steady state, the *total* transport across any parallel of latitude must
be zero, so it is impossible for the Sverdrup balance to be valid across
the entire basin. There must be a region---a boundary layer---where the
Sverdrup balance is violated, so that the interior Sverdrup transport to
the south can be returned to the north. One might expect that there
would be boundary layers on both the eastern and the western boundaries,
but it turns out that the significant boundary layer occurs only on the
western side.

This is a robust result. Four separate types of model, or argument, can
be used to reach the same conclusion: the return flow is entirely in a
western boundary current. Like the Sverdrup balance, *all of the
arguments depend crucially on the variation of Coriolis parameter with
latitude,* that is, the "beta effect". Separately, the arguments involve

-   simple linear damping of momentum, equivalent to bottom friction in
    a homogeneous (constant density) model;

-   lateral friction;

-   nonlinearity;

-   or time-dependence, that is, the "spinup" from an initial state of
    rest to the mean circulation.

Each of these mechanisms modifies the simple, steady, linear vorticity
balance in such a way as to permit a strong return flow only on the
western boundary. The last argument is the most profound, general, and
directly applicable to the ocean. The first two are of great historical
importance and nicely isolate the essential role of the beta effect, but
they are so idealized that it does not make sense to apply them directly
to the ocean. The third mechanism, nonlinearity, is more relevant to
real western boundary currents.

## Stommel's model: simple damping {#stommels-model-simple-damping .unnumbered}

The first and simplest explanation of "The westward intensification of
wind-driven ocean currents" was given by Henry Stommel in 1948, in a
paper of that title (in Trans. Amer. Geophys. Union, 29, 202--206). He
used a rectangular, flat-bottomed, homogeneous ocean with a simple
pattern of wind stress and a steady, linear, vertically-integrated
momentum balance. Wind stress and a damping term then appear as body
forces. It turns out that this simple linear momentum damping is
equivalent to the net effect of a bottom Ekman layer---they look the
same in the vorticity balance, causing a linear vorticity damping. With
this model, Stommel showed that the circulation in a basin with constant
Coriolis parameter ($f$) is symmetric in the east-west direction; but
when $f$ varies linearly with latitude, the circulation becomes much
weaker and highly asymmetric, with the Sverdrup balance in the interior
and with a frictional boundary layer returning the meridional flow on
the western side of the basin.

The vorticity balance in this model can be written as
$$\frac{\partial \zeta}{\partial t}+ \beta v = \frac{1}{\rho}\frac{1}{H}\mbox{curl}_z(\vec{\tau}_w)
   - R\zeta, \label{E-dampedvort}$$ where $R$ is a damping coefficient,
$H$ is the depth of the basin, and both $\zeta$ and $v$ are
depth-averaged. The time derivative is actually zero, because we are
looking for a steady solution; I left it in to show how the damping term
would work in a time-dependent situation. Then the rate of change of
vorticity would be proportional to minus the vorticity itself, and if
there were no other terms in the equation, any initial vorticity pattern
would just decay exponentially.

In the interior of the basin, we have the Sverdrup balance:
$$\beta v = \frac{1}{\rho}\frac{1}{H}\mbox{curl}_z(\vec{\tau}_w).
   \label{E-sver}$$ Now suppose we have a frictional boundary layer on
the eastern or western boundary, in which the primary balance is
$$\beta v =    - R\zeta. \label{E-stommelwbc}$$ Can this happen on
either the eastern or the western boundary? The difference between the
two cases is the sign of the vorticity in the layer. If the layer is on
the west, there must be a northward velocity (for our northern
hemisphere mid-latitude gyre example) increasing to a maximum at the
boundary. We have no lateral friction, so the appropriate boundary
condition is free-slip, hence the velocity maximum on the boundary. The
relative vorticity is then negative in this current. Multiplying by the
$-R$ on the right of
([\[E-stommelwbc\]](#E-stommelwbc){reference-type="ref"
reference="E-stommelwbc"}), we get a positive term. On the left, we also
have a positive term, because $v$ is positive, that is, northward. Hence
the balance in ([\[E-stommelwbc\]](#E-stommelwbc){reference-type="ref"
reference="E-stommelwbc"}) works for the western boundary case. If we
tried to put the current on the eastern side, the one thing that would
change would be the sign of the relative vorticity ($\zeta$). The right
hand side of the equation would now be negative, but the left would
still be positive---hence no balance is possible, and the current can't
exist on the eastern boundary.

## Munk's model: lateral friction {#munks-model-lateral-friction .unnumbered}

A somewhat more complex model was published in 1950 by Walter Munk.
Instead of Stommel's linear friction, he used a constant lateral eddy
viscosity, but no bottom friction. The boundary condition is then
no-slip, that is, both velocity components equal zero on the boundary,
and the structure of the resulting boundary layer is more complicated
than in Stommel's model. The details are not important here. The
important point is that the conclusion from Munk's model is exactly the
same as from Stommel's: the frictional boundary layer that carries the
poleward return flow to balance the equatorward Sverdrup interior flow
can occur only on the western boundary.

## Morgan's and Charney's models: nonlinearity {#morgans-and-charneys-models-nonlinearity .unnumbered}

A few years later, after discussions with Stommel, Morgan and Charney
independently developed inertial models, showing that at least in their
formation regions, western boundary currents might not depend on
friction at all. The main idea is that potential vorticity is conserved
*following a water column*, so a western boundary return flow to the
north (that is, $f$ is increasing) requires some combination of
increasing water column height and increasingly negative relative
vorticity. To keep the argument as simple as possible, consider a model
in a homogeneous ocean with a flat bottom, so that water column height
is constant. (The Morgan and Charney models considered the upper layer
in a two-layer ocean, so spatially-varying water column height was
important, but this does not change the basic argument.) The vorticity
balance would then be
$$\mbox{$\vec{u}$}\cdot \nabla\zeta + \beta v = 0.  \label{E-nlvort}$$
Just as in the Stommel model, the boundary current will satisfy the
free-slip conditions, will be strongest at the boundary, and will
therefore have negative relative vorticity if it is on the western
boundary. ([\[E-nlvort\]](#E-nlvort){reference-type="ref"
reference="E-nlvort"}) then requires the first term---the downstream
component of the relative vorticity gradient---to be negative, because
$\beta v$ is positive. This works. The negative vorticity gets stronger
downstream as the boundary current gets narrower and/or carries more
transport. In contrast, a northward boundary current on the eastward
boundary would have to have positive relative vorticity, but the $\beta$
term would cause this positive vorticity to weaken downstream.

## Pedlosky's Rossby wave argument: spinup {#pedloskys-rossby-wave-argument-spinup .unnumbered}

Still later, people developed models not just of the steady circulation,
but of how the circulation would respond to change in the wind stress.
In 1965, Pedlosky pointed out that the dynamics of the time-dependent
case actually provides another good explanation for westward
intensification. The argument rests on the characteristics of Rossby
waves, which we will study in some detail later. For now we just note a
few essentials. Rossby waves are large-scale potential vorticity
disturbances that propagate as waves. Their propagation results from the
change in Coriolis parameter with latitude, that is, the beta effect.
Unlike the sorts of waves with which we are most familiar, Rossby waves
propagate in a highly *anisotropic* manner: their phase propagation
always has a westward component, and although they can propagate energy
either east or west, the Rossby waves that propagate energy to the west
have large scales and relatively high propagation speeds, while those
propagating energy to the east have small east-west scales and are so
slow that they tend to get dissipated before they get very far. Westward
(long) Rossby waves are reflected at the western boundary as (short)
eastward Rossby waves. Hence energy (and "information" about the
interior of the basin) tends to pile up in small scales on the western
boundary, forming a western boundary current.

Pedlosky's Rossby wave argument provides the most fundamental
explanation of *why* the boundary layer is in the west; it is implicit
in any model of the steady western boundary current, including the
models discussed above.

## Topography {#topography .unnumbered}

Recently, attention has been focussed on the importance of ocean bottom
topography in the dynamics of western boundary currents. Contrary to all
of the steady models discussed above, there is evidence that in most
western boundary currents, the change in water column height associated
with a downslope (for poleward-going western boundary currents) or
upslope (for equatorward) component of flow is of primary importance;
potential vorticity is approximately conserved following a water parcel
in a western boundary current over much of its path.

## Conclusion {#conclusion .unnumbered}

The one essential element in the westward intensification of ocean
currents is the beta effect, as Stommel showed. Given that, a western
boundary current theory can be constructed in many ways. The models and
ideas discussed above are not intended to provide a realistic picture of
an actual western boundary current, but to illustrate some of the
dynamical concepts and balances that might be included in such a
picture.

The most fundamental concept to remember is the Pedlosky argument:
information about forcing at low frequencies propagates effectively only
to the west. This information about vorticity forcing propagates via
potential vorticity waves---Rossby waves---which depend on the beta
effect. Unlike the eastern boundary, the western boundary "knows" about
all the forcing in the interior, and therefore some sort of western
boundary layer must form in response to that forcing.

:::{admonition} Source
The original source of this content can be found in 
[PDF form](https://currents.soest.hawaii.edu/ocn620_files/notes/wbc.pdf)
 from Eric Firing's course notes.
:::
